@@ -1,8 +1,6 @@
 
-# $Id: zInitMethods.R 601 2016-11-07 13:04:33Z thothorn $
+# $Id: zInitMethods.R 659 2019-03-04 07:53:45Z thothorn $
 
-### moved to coin as of coin 1.0-24
-if (FALSE) {
 setMethod(f = "initialize", signature = "ExpectCovar",
     definition = function(.Object, pq = 1) {
         pq <- as.integer(pq)
@@ -25,8 +23,6 @@ setMethod(f = "initialize", signature = "ExpectCovarInfluence",
     }
 )
 
-}
-
 ### done at C level as of party 1.1-0 but still used in Utils (for tests)
 setMethod(f = "initialize", signature = "LinStatExpectCovar",
     definition = function(.Object, p, q) {
